@@ -25,13 +25,14 @@ from _pytask.path import find_common_ancestor
 from _pytask.path import relative_to
 from _pytask.pluginmanager import get_plugin_manager
 from _pytask.session import Session
+from pybaum.tree_util import tree_just_flatten
 from rich.text import Text
 from rich.tree import Tree
 
 
 if TYPE_CHECKING:
     from typing import NoReturn
-    from _pytask.nodes import MetaTask
+    from _pytask.nodes import Task
 
 
 @hookimpl(tryfirst=True)
@@ -107,7 +108,7 @@ def collect(**config_from_cli: Any | None) -> NoReturn:
     sys.exit(session.exit_code)
 
 
-def _select_tasks_by_expressions_and_marker(session: Session) -> list[MetaTask]:
+def _select_tasks_by_expressions_and_marker(session: Session) -> list[Task]:
     """Select tasks by expressions and marker."""
     all_tasks = {task.name for task in session.tasks}
     remaining_by_mark = select_by_mark(session, session.dag) or all_tasks
@@ -118,34 +119,29 @@ def _select_tasks_by_expressions_and_marker(session: Session) -> list[MetaTask]:
 
 
 def _find_common_ancestor_of_all_nodes(
-    tasks: list[MetaTask], paths: list[Path], show_nodes: bool
+    tasks: list[Task], paths: list[Path], show_nodes: bool
 ) -> Path:
     """Find common ancestor from all nodes and passed paths."""
     all_paths = []
     for task in tasks:
         all_paths.append(task.path)
         if show_nodes:
-            all_paths.extend(
-                [
-                    node.path
-                    for attr in ("depends_on", "produces")
-                    for node in getattr(task, attr).values()
-                ]
-            )
+            all_paths.extend(map(lambda x: x.path, tree_just_flatten(task.depends_on)))
+            all_paths.extend(map(lambda x: x.path, tree_just_flatten(task.produces)))
 
     common_ancestor = find_common_ancestor(*all_paths, *paths)
 
     return common_ancestor
 
 
-def _organize_tasks(tasks: list[MetaTask]) -> dict[Path, list[MetaTask]]:
+def _organize_tasks(tasks: list[Task]) -> dict[Path, list[Task]]:
     """Organize tasks in a dictionary.
 
     The dictionary has file names as keys and then a dictionary with task names and
     below a dictionary with dependencies and targets.
 
     """
-    dictionary: dict[Path, list[MetaTask]] = {}
+    dictionary: dict[Path, list[Task]] = {}
     for task in tasks:
         dictionary[task.path] = dictionary.get(task.path, [])
         dictionary[task.path].append(task)
@@ -158,7 +154,7 @@ def _organize_tasks(tasks: list[MetaTask]) -> dict[Path, list[MetaTask]]:
 
 
 def _print_collected_tasks(
-    dictionary: dict[Path, list[MetaTask]],
+    dictionary: dict[Path, list[Task]],
     show_nodes: bool,
     editor_url_scheme: str,
     common_ancestor: Path,
@@ -167,7 +163,7 @@ def _print_collected_tasks(
 
     Parameters
     ----------
-    dictionary : Dict[Path, List["MetaTask"]]
+    dictionary : Dict[Path, List["Task"]]
         A dictionary with path on the first level, tasks on the second, dependencies and
         products on the third.
     show_nodes : bool
@@ -201,7 +197,9 @@ def _print_collected_tasks(
             )
 
             if show_nodes:
-                for node in sorted(task.depends_on.values(), key=lambda x: x.path):
+                for node in sorted(
+                    tree_just_flatten(task.depends_on), key=lambda x: x.path
+                ):
                     reduced_node_name = relative_to(node.path, common_ancestor)
                     url_style = create_url_style_for_path(node.path, editor_url_scheme)
                     task_branch.add(
@@ -213,7 +211,9 @@ def _print_collected_tasks(
                         )
                     )
 
-                for node in sorted(task.produces.values(), key=lambda x: x.path):
+                for node in sorted(
+                    tree_just_flatten(task.produces), key=lambda x: x.path
+                ):
                     reduced_node_name = relative_to(node.path, common_ancestor)
                     url_style = create_url_style_for_path(node.path, editor_url_scheme)
                     task_branch.add(
