@@ -13,6 +13,14 @@ import pluggy
 from rich.traceback import Traceback
 
 
+__all__ = [
+    "format_exception_without_traceback",
+    "remove_internal_traceback_frames_from_exc_info",
+    "remove_traceback_from_exc_info",
+    "render_exc_info",
+]
+
+
 _PLUGGY_DIRECTORY = Path(pluggy.__file__).parent
 _PYTASK_DIRECTORY = Path(_pytask.__file__).parent
 
@@ -26,7 +34,9 @@ def render_exc_info(
     traceback: str | TracebackType,
     show_locals: bool = False,
 ) -> str | Traceback:
-    if isinstance(traceback, str):
+    """Render an exception info."""
+    # Can be string if send from subprocess by pytask-parallel.
+    if isinstance(traceback, str):  # pragma: no cover
         renderable = traceback
     else:
         renderable = Traceback.from_exception(
@@ -92,10 +102,12 @@ def _filter_internal_traceback_frames(
 
     """
     frame = exc_info[2]
-    for frame in _yield_traceback_frames(frame):
-        if frame is None or not _is_internal_or_hidden_traceback_frame(frame, exc_info):
+    for frame_ in _yield_traceback_frames(frame):
+        if frame_ is None or not _is_internal_or_hidden_traceback_frame(
+            frame_, exc_info
+        ):
             break
-    return frame
+    return frame_
 
 
 def _yield_traceback_frames(
